@@ -2,6 +2,7 @@
 import torch
 import torch.nn as nn
 import torch.optim as optim
+from typing import Any
 
 
 class LinearRegressor(nn.Module):
@@ -254,7 +255,7 @@ class LinearRegressor(nn.Module):
 
         self.network = nn.Sequential(*layers)
 
-    def forward(self, x):
+    def forward(self, x) -> "torch.Tensor":
         """Forward pass through the network.
 
         Args:
@@ -272,7 +273,9 @@ class LinearRegressor(nn.Module):
         """
         return self.network(x)
 
-    def get_optimizer(self, optimizer_name="Adam", lr=None, **kwargs):
+    def get_optimizer(
+        self, optimizer_name: str = "Adam", lr: float = None, **kwargs: Any
+    ) -> "optim.Optimizer":
         """Get a PyTorch optimizer configured for this model.
 
         Convenience method to instantiate optimizers using string names instead of
@@ -296,7 +299,7 @@ class LinearRegressor(nn.Module):
                 weight_decay for AdamW, alpha for RMSprop).
 
         Returns:
-            torch.optim.Optimizer: Configured optimizer instance ready for training.
+            optim.Optimizer: Configured optimizer instance ready for training.
 
         Raises:
             ValueError: If the specified optimizer name is not found in torch.optim or
@@ -442,7 +445,7 @@ class LinearRegressor(nn.Module):
         # Map unified learning rate to optimizer-specific learning rate
         try:
             lr_actual = map_lr(lr, optimizer_name)
-        except ValueError as e:
+        except ValueError:
             # If optimizer not in map_lr, try to use it directly with torch.optim
             if not hasattr(optim, optimizer_name):
                 raise ValueError(
